@@ -1,8 +1,9 @@
 use 5.14.0;
 
 package Dist::Zilla::MintingProfile::MapMetro::Map;
-$Dist::Zilla::MintingProfile::MapMetro::Map::VERSION = '0.1300';
-# VERSION
+
+our $VERSION = '0.1400'; # VERSION
+# ABSTRACT: Mint a Map::Metro Map distribution
 
 use Moose;
 with 'Dist::Zilla::Role::MintingProfile::ShareDir';
@@ -11,12 +12,18 @@ with 'Dist::Zilla::Role::MintingProfile::ShareDir';
 
 __END__
 
+=pod
+
 =encoding utf-8
 
 =head1 NAME
 
 Dist::Zilla::MintingProfile::MapMetro::Map - Mint a Map::Metro Map distribution
 
+=head1 VERSION
+
+Version 0.1400, released 2015-01-13.
+
 =head1 SYNOPSIS
 
   $ dzil new -P MapMetro::Map  Map::Metro::Plugin::Map::[Cityname]
@@ -31,17 +38,25 @@ L<Map::Metro>
 
 L<Map::Metro::Plugin::Map>
 
+L<Task::MapMetro::Dev>
+
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Dist-Zilla-MintingProfile-MapMetro-Map>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/Dist-Zilla-MintingProfile-MapMetro-Map>
+
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 - Erik Carlsson
+This software is copyright (c) 2015 by Erik Carlsson.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
